import { FrameEventSource, SDKEventSource } from "./consts";
export interface RemoteBrowserClientSettings {
    userName: string;
    role: string;
    allowFullscreen: boolean;
    disableAudio: boolean;
    targetOrigin: string;
}
export declare type RemoteBrowserCreateClientSettings = {
    iframeSource: string;
    instanceURN: string;
} & Partial<RemoteBrowserClientSettings>;
export declare type RemoteBrowserGetEmbedURLParams = RemoteBrowserCreateClientSettings;
declare type BaseEvent<S, E, D = null> = {
    source: S;
    name: E;
    data: D;
};
declare type SDKEvent<E, D = null> = BaseEvent<typeof SDKEventSource, E, D>;
declare type FrameEvent<E, D = null> = BaseEvent<typeof FrameEventSource, E, D>;
declare type EventOpenInCurrentTab = SDKEvent<"openInCurrentTab", {
    url: string;
}>;
declare type EventOpenInNewTab = SDKEvent<"openInNewTab", {
    url: string;
}>;
declare type EventStartRecording = SDKEvent<"startRecording">;
declare type EventStopRecording = SDKEvent<"stopRecording">;
declare type EventError = FrameEvent<"error", {
    error: string | Error;
    eventSource?: "openInCurrentTab" | "openInNewTab" | "startRecording" | "stopRecording";
}>;
export declare type EmbedRemoteBrowserSDKEvent = EventOpenInCurrentTab | EventOpenInNewTab | EventStartRecording | EventStopRecording;
export declare type EmbedRemoteBrowserFrameEvent = EventError;
export interface EventBusEvents {
    "openInCurrentTab:error": string | Error;
    "openInNewTab:error": string | Error;
    "startRecording:error": string | Error;
    "stopRecording:error": string | Error;
}
export {};
